==> yak-dev-couchace-1.2.2-sources.jar: org/crazyyak/dev/couchace/DefaultCouchServer.java <==
package org.crazyyak.dev.couchace;

import com.couchace.core.api.CouchServer;
import com.couchace.core.api.CouchSetup;
import com.couchace.core.api.http.CouchHttpException;
import com.couchace.core.spi.http.CouchHttpClient;
import com.couchace.core.spi.json.CouchJsonStrategy;
import com.couchace.jackson.JacksonCouchJsonStrategy;
import com.couchace.jersey.JerseyCouchHttpClient;
import com.fasterxml.jackson.databind.ObjectMapper;
import org.crazyyak.dev.common.EnvUtils;
import org.crazyyak.dev.domain.translation.jackson.YakJacksonMapper;

public class DefaultCouchServer extends CouchServer {

  public DefaultCouchServer() {
    this(getCouchSetup(new YakJacksonMapper()));
  }

  public DefaultCouchServer(CouchSetup couchSetup) {
    super(couchSetup);
    validateConnection(couchSetup);
  }

  public DefaultCouchServer(ObjectMapper mapper) {
    this(getCouchSetup(mapper));
  }

  public DefaultCouchServer(CouchHttpClient couchHttpClient,
                            CouchJsonStrategy couchJsonStrategy) {

    this(couchHttpClient,
         couchJsonStrategy,
         getAppUrl(),
         getAppUserName(),
         getAppPassword());
  }

  public DefaultCouchServer(CouchHttpClient couchHttpClient,
                            CouchJsonStrategy couchJsonStrategy,
                            String url, String userName, String password) {

    this(new CouchSetup(url)
      .setUserName(userName)
      .setPassword(password)
      .setHttpClient(couchHttpClient)
      .setJsonStrategy(couchJsonStrategy));
  }

  public static CouchSetup getCouchSetup(ObjectMapper mapper) {

    return new CouchSetup(getAppUrl())
        .setUserName(getAppUserName())
        .setPassword(getAppPassword())
        .setHttpClient(JerseyCouchHttpClient.class)
        .setJsonStrategy(new JacksonCouchJsonStrategy(mapper));
  }

  public void validateConnection(CouchSetup couchSetup) {
    try {
      assertConnection();
    } catch (CouchHttpException e) {
      String msg = String.format("Unable to verify connection for %s at %s.", couchSetup.getUserName(), couchSetup.getUrl());
      throw new CouchHttpException(e.getStatusCode(), msg);
    }
  }

  public static String getAppPassword() {
    String userName = getAppUserName();
    return EnvUtils.findProperty("app.couch.password", userName);
  }

  public static String getAppUserName() {
    return EnvUtils.findProperty("app.couch.userName", "app-user");
  }

  public static String getAppUrl() {
    return EnvUtils.findProperty("app.couch.url", "http://localhost:5984");
  }
}

==> yak-dev-couchace-2.0.0-sources.jar: org/crazyyak/dev/couchace/DefaultCouchServer.java <==
package org.crazyyak.dev.couchace;

import com.couchace.core.api.*;
import com.couchace.core.api.http.CouchHttpException;
import com.couchace.core.spi.http.CouchHttpClient;
import com.couchace.core.spi.json.CouchJsonStrategy;
import com.couchace.jackson.JacksonCouchJsonStrategy;
import com.couchace.jackson.internal.CouchJacksonModel;
import com.couchace.jersey.JerseyCouchHttpClient;
import com.fasterxml.jackson.databind.Module;
import com.fasterxml.jackson.datatype.joda.JodaModule;
import org.crazyyak.dev.common.EnvUtils;
import org.crazyyak.dev.domain.translation.jackson.YakJacksonModule;

public class DefaultCouchServer extends CouchServer {

  public DefaultCouchServer(CouchSetup couchSetup) {
    super(couchSetup);
    validateConnection(couchSetup);
  }

  public DefaultCouchServer() {
    this(new CouchSetup(getAppUrl())
        .setUserName(getAppUserName())
        .setPassword(getAppPassword())
        .setHttpClient(JerseyCouchHttpClient.class)
        .setJsonStrategy(new JacksonCouchJsonStrategy(
            new CouchJacksonModel(),
            new JodaModule(),
            new YakJacksonModule()
        )));
  }

  public DefaultCouchServer(Module[] modules) {
    this(new CouchSetup(getAppUrl())
        .setUserName(getAppUserName())
        .setPassword(getAppPassword())
        .setHttpClient(JerseyCouchHttpClient.class)
        .setJsonStrategy(new JacksonCouchJsonStrategy(modules)));
  }

  public DefaultCouchServer(CouchHttpClient couchHttpClient,
                            CouchJsonStrategy couchJsonStrategy) {

    this(new CouchSetup(getAppUrl())
        .setUserName(getAppUserName())
        .setPassword(getAppPassword())
        .setHttpClient(couchHttpClient)
        .setJsonStrategy(couchJsonStrategy));
  }

  public DefaultCouchServer(CouchHttpClient couchHttpClient,
                            CouchJsonStrategy couchJsonStrategy,
                            String url, String userName, String password) {

    this(new CouchSetup(url)
      .setUserName(userName)
      .setPassword(password)
      .setHttpClient(couchHttpClient)
      .setJsonStrategy(couchJsonStrategy));
  }

  public void validateConnection(CouchSetup couchSetup) {
    try {
      assertConnection();

    } catch (CouchHttpException e) {
      String msg = String.format("Unable to verify connection for %s at %s.", couchSetup.getUserName(), couchSetup.getUrl());
      throw new CouchHttpException(e.getStatusCode(), msg);
    }
  }

  public static String getAppPassword() {
    String userName = getAppUserName();
    return EnvUtils.findProperty("app.couch.password", userName);
  }

  public static String getAppUserName() {
    return EnvUtils.findProperty("app.couch.userName", "app-user");
  }

  public static String getAppUrl() {
    return EnvUtils.findProperty("app.couch.url", "http://localhost:5984");
  }
}
